@@ -8,7 +8,7 @@ import (
 	"golang.org/x/sync/errgroup"
 )
 
-func Test(t *testing.T) {
+func TestPubSub(t *testing.T) {
 	is := is.New(t)
 	ps := pubsub.New()
 	ps.Publish("toast", []byte("nothing to publish to yet"))
@@ -23,3 +23,10 @@ func Test(t *testing.T) {
 	is.NoErr(eg.Wait())
 	sub.Close()
 }
+
+func TestCloseTwice(t *testing.T) {
+	ps := pubsub.New()
+	sub := ps.Subscribe("toast")
+	sub.Close()
+	sub.Close()
+}
